# 🗿✂️📄 Kanobu
## 🗣 Localisation
| Language      | Locale    | Status    | Language     | Status    | Locale   |
|---------------|-----------|-----------|--------------|-----------|----------|
| 🇷🇺 Russian    | `ru_RU`   | 👍 stable | 🇩🇪 German     | ⚠️ beta    | `de_DE` |
| 🇺🇦 Ukrainian  | `ua_UA`   | 👍 stable | 🇬🇧 English    | 👍 stable  | `en_EN` |
| 🇫🇷 French     | `fr_FR`   | ⚠️ beta   | 🇪🇸 Spanish    | 🗓 plans   | `es_ES` |
| 🇨🇳 Chinese    | `cn_CN`   | ❌ none   | 🇵🇹 Portuguese | 🗓 plans   | `pt_PT` |
| 🇵🇱 Polish     | `pl_PL`   | 🗓 plans  | 🇮🇹 Italian    | ⚠️ beta    | `it_IT` |
| 🇹🇷 Turkish    | `tr_TR`   | ❌ none   | 🇸🇦 Arabien    | ❌ none    | `sa_SA` |
| 🇰🇷 Korean     | `kr_KR`   | ❌ none   | 🇮🇳 Hindi      | ❌ none    | `in_IN` |
| 🇭🇺 Hungarian  | `hu_HU`   | 🗓 plans  | 😀 Emoji      | ⚠️ beta    | `em_EM` |

## 🚀 Start
To start, run this code:
```
pip install kanobu
kanobu
```
## ⚙️ Options
| Option    | Information                                                                |
|-----------|----------------------------------------------------------------------------|
| `dev`     | To get developers functions, and logs about variables and other parameters |
| `lang`    | For set default language. All languages placed in locale folder            |
| `version` | To get version                                                             |
| `choise`  | For enter choice without `input()`                                         |

## 🔨 Dependencies
### 🖌 [colorama](https://github.com/tartley/colorama)
Simple cross-platform colored terminal text in Python. Support `cmd`, `bash`
### 📄 [pyyaml](https://github.com/yaml/pyyaml)
The next generation YAML parser and emitter for Python.
## 📰 Trello (ru)
You can subscribe to [trello](https://trello.com/b/o0ozs1XT) to get information about the new functionality
